@@ -9,10 +9,10 @@ import tkinter.ttk as ttk
 import tkinter.tix as tix
 from tkdev.devresize import DevResize
 from tkdev.devicon import Icon_Empty
-from ctypes import windll
+from ctypes import windll, Structure, c_int, c_size_t, POINTER, sizeof
+from ctypes.wintypes import BOOL, CHAR, COLORREF, UINT
 from os import environ
-from winrt import *
-
+from enum import Enum
 try:
     from win32gui import *
     from win32con import *
@@ -25,11 +25,17 @@ try:
     import win32mica as mc
 except ImportError:
     pass
+try:
+    from BlurWindow.blurWindow import GlobalBlur
+except ImportError:
+    pass
 try:
     import darkdetect
 except ImportError:
     pass
 
+dwm = windll.dwmapi
+
 windll.shcore.SetProcessDpiAwareness(1)
 ScaleFactor = windll.shcore.GetScaleFactorForDevice(0)
 
@@ -40,11 +46,65 @@ Auto = "auto"
 Light = "light"
 Dark = "dark"
 
+DWMWA_USE_IMMERSIVE_DARK_MODE = 20
+
+
+class DWMWINDOWATTRIBUTE(Enum):
+    DWMWA_NCRENDERING_ENABLED = 1
+    DWMWA_NCRENDERING_POLICY = 2
+    DWMWA_TRANSITIONS_FORCEDISABLED = 3
+    DWMWA_ALLOW_NCPAINT = 4
+    DWMWA_CAPTION_BUTTON_BOUNDS = 5
+    DWMWA_NONCLIENT_RTL_LAYOUT = 6
+    DWMWA_FORCE_ICONIC_REPRESENTATION = 7
+    DWMWA_FLIP3D_POLICY = 8
+    DWMWA_EXTENDED_FRAME_BOUNDS = 9
+    DWMWA_HAS_ICONIC_BITMAP = 10
+    DWMWA_DISALLOW_PEEK = 11
+    DWMWA_EXCLUDED_FROM_PEEK = 12
+    DWMWA_CLOAK = 13
+    DWMWA_CLOAKED = 14
+    DWMWA_FREEZE_REPRESENTATION = 15
+    DWMWA_PASSIVE_UPDATE_MODE = 16
+    DWMWA_USE_HOSTBACKDROPBRUSH = 17
+    DWMWA_USE_IMMERSIVE_DARK_MODE = 18
+    DWMWA_WINDOW_CORNER_PREFERENCE = 19
+    DWMWA_BORDER_COLOR = 20
+    DWMWA_CAPTION_COLOR = 21
+    DWMWA_TEXT_COLOR = 22
+    DWMWA_VISIBLE_FRAME_BORDER_THICKNESS = 23
+    DWMWA_LAST = 24
+
+
+class DWM_SYSTEMBACKDROP_TYPE(Structure):
+    _fields_ = [
+        ("Attribute", c_int),
+        ("Data", POINTER(c_int)),
+        ("SizeOfData", c_size_t)
+    ]
+
+
+def dwm_set_window_attribute(window: tk.Tk, attribute, value):
+    dwm.DwmSetWindowAttribute(GetParent(window.winfo_id()), attribute, value)
+
+
+def window_dark(window: tk.Tk):
+    dwm.DwmSetWindowAttribute(GetParent(window.winfo_id()), DWMWA_USE_IMMERSIVE_DARK_MODE, True)
+
+
+def window_light(window: tk.Tk):
+    dwm.DwmSetWindowAttribute(GetParent(window.winfo_id()), DWMWA_USE_IMMERSIVE_DARK_MODE, False)
+
+
+def window_acrylic(window: tk.Tk, Dark=False):
+    GlobalBlur(GetParent(window.winfo_id()), Dark=True)
+
 
 def window_long(window: tk.Tk, long):
     def long():
         hwnd = GetParent(window.winfo_id())
         res = SetWindowLong(hwnd, GWL_STYLE, GetWindowLong(hwnd, GWL_STYLE) & ~long)
+
     self.after(1, long)
 
 
@@ -60,7 +120,8 @@ def window_tiled(window: tk.Tk):
 
 def widget_max(widget: tk.Widget):
     hwnd = GetParent(widget.winfo_id())
-    res = DefWindowProc(hwnd, HTHELP, None, None)
+    res = DefWindowProc(hwnd, WM_NCHITTEST, None, None)
+    print(res)
 
 
 def window_alpha(window: tk.Tk, alpha: int):
@@ -758,7 +819,19 @@ class DevWindow(tk.Tk):
         self.geometry("630x300")
         self.iconbitmap(Icon_Empty)
 
-    def wm_mica(self, mode: str = Literal["auto", "light", "dark"], all: bool = False):
+    def wm_acrylic(self, mode: Literal["auto", "light", "dark"] = Auto):
+        if mode == "auto":
+            if darkdetect.isLight():
+                window_acrylic(self, Dark=False)
+            if darkdetect.isDark():
+                window_acrylic(self, Dark=True)
+        elif mode == "light":
+            window_acrylic(self, Dark=False)
+        elif mode == "dark":
+            window_acrylic(self, Dark=True)
+        self.update()
+
+    def wm_mica(self, mode: Literal["auto", "light", "dark"] = Auto, all: bool = False):
         if platform.system() == "Windows":
             if all:
                 self.configure(background=self.cget("background"))
@@ -842,10 +915,5 @@ class DevToplevel(tk.Toplevel, DevWindow):
 
 
 if __name__ == '__main__':
-    import sv_ttk
     Root = DevWindow()
-    Root.mica(Dark)
-    sv_ttk.use_dark_theme()
-    Button = ttk.Button(Root, text="Click Me")
-    Button.pack(fill=tk.BOTH, expand=tk.YES, pady=20, padx=20)
     Root.run()
